#
# spec file for package python-zope.hookable
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2013-2022 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-zope.hookable%{psuffix}
Version:        7.0
Release:        2.1
Summary:        Zope hookable
License:        ZPL-2.1
URL:            https://github.com/zopefoundation/zope.hookable
Source:         https://files.pythonhosted.org/packages/source/z/zope.hookable/zope_hookable-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION documentation requirements
BuildRequires:  python3-Sphinx
BuildRequires:  python3-sphinx_rtd_theme
# /SECTION
# SECTION testing requirements
%if %{with test}
BuildRequires:  %{python_module zope.hookable}
BuildRequires:  %{python_module zope.testing}
%endif
# /SECTION
%python_subpackages

%description
Hookable object support.

Support the efficient creation of hookable objects, which are callable objects
that are meant to be replaced by other callables, at least optionally.

The idea is you create a function that does some default thing and make it
hookable. Later, someone can modify what it does by calling its sethook method
and changing its implementation. All users of the function, including those
that imported it, will see the change.

%package     -n %{name}-doc
Summary:        Zope hookable
Provides:       %{python_module zope.hookable-doc = %{version}}
BuildArch:      noarch

%description -n %{name}-doc
This package contains documentation files for %{name}.

%prep
%autosetup -p1 -n zope_hookable-%{version}
rm -rf zope.hookable.egg-info

%build
%if !%{with test}
%pyproject_wheel
sphinx-build -b html docs build/sphinx/html && rm -r build/sphinx/html/.{buildinfo,doctrees} build/sphinx/html/objects.inv
%endif

%install
%if !%{with test}
%pyproject_install
%{python_expand rm -f %{buildroot}%{$python_sitearch}/zope/hookable/_zope_hookable.c
  %fdupes %{buildroot}%{$python_sitearch}
}
%endif

%check
%if %{with test}
pushd src
%pyunittest 'zope.hookable.tests.test_hookable.test_suite'
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst COPYRIGHT.txt README.rst
%dir %{python_sitearch}/zope
%{python_sitearch}/zope/hookable
%{python_sitearch}/zope.hookable-%{version}.dist-info
%{python_sitearch}/zope.hookable-%{version}*-nspkg.pth
%endif

%if !%{with test}
%files -n %{name}-doc
%doc build/sphinx/html/
%endif

%changelog
* Wed Jan 22 2025 Steve Kowalik <steven.kowalik@suse.com>
- Explicitly BuildRequire sphinx_rtd_theme.
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 7.0:
  * C extension now enables multi-phase module initialization
    (PEP 489). For CPython >= 3.11, the hookable type is now a
    heap-allocated type.  See:
    https://docs.python.org/3.13/howto/isolating-extensions.html
  * Drop support for Python 3.7.
  * Add support for Python 3.13.
  * Build windows wheels on GHA.
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0:
  * Drop support for Python 2.7, 3.5, 3.6.
  * Add support for Python 3.12.
* Wed Jul 26 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop sphinx doctrees for reproducible builds
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed May  3 2023 Martin Liška <mliska@suse.cz>
- Use sphinx-build and do not depend on removed build_sphinx
  in Sphinx 7.0 (boo#1211051).
* Wed Feb  1 2023 Ben Greiner <code@bnavigator.de>
- Explicitly require python3-Sphinx for building the docs. It could
  have been omitted from %%pythons for %%python_module in a 15.X
  backport project.
* Mon Dec  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.4
  * Add support for building arm64 wheels on macOS.
* Tue Nov  8 2022 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file, make rpmlint happy.
- -doc subpackage should be noarch.
* Sun Nov  6 2022 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 5.3
  * Add support for the final release of Python 3.11.
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.2
  * Add support for Python 3.10 and 3.11 (as of 3.11.0rc1).
  * Disable unsafe math optimizations in C code. See pull request 25.
* Wed Oct 13 2021 pgajdos@suse.com
- update to version 5.1.0
  - Add support for Python 3.9.
  - Create Linux aarch64 wheels.
* Wed Oct 13 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
- added sources
  + _multibuild
* Wed Apr  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in py2 package in doc subpkg
* Mon Mar 16 2020 pgajdos@suse.com
- version update to 5.0.1
  - Stop using the setuptools ``Feature`` class, allowing this
    project to be built from source with newer versions of setuptools
    that remove that functionality.
* Tue Jan 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 5.0.0
  * Add support for Python 3.7 and 3.8.
  * Drop support for Python 3.4.
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Fri Apr  5 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.2.0
  * Add support for Python 3.5 and 3.6.
  * Drop support for Python 2.6, 3.2 and 3.3.
  * Expose the __doc__ (and, where applicable, __bases__ and __dict__)
    of the hooked object. This lets Sphinx document them.
  * Respect PURE_PYTHON at runtime.
* Sat Jul  8 2017 aloisio@gmx.com
- Converted to single-spec
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.0.4:
  * Added support for Python 3.4.
- additional changes from version 4.0.3:
  * Updated boostrap.py to version 2.2.
  * Fixed extension compilation on Py3k.
- additional changes from version 4.0.2:
  * Fleshed out PyPI Trove classifiers.
- point the source URL to pypi
- rename CHANGES.txt to CHANGES.rst: changed upstream
- rename README.txt to README.rst: changed upstream
* Mon Jul 29 2013 hpj@urpla.net
- version 4.0.1: initial build
